#
#  Copyright 1999-2001 Illinois Institute of Technology
#
#  See the file "LICENSE" for information on usage and redistribution
#  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#

proc move_filters { record_list grid } {

	set filter1 [ $record_list get_record "filter1" ]
	set filter2 [ $record_list get_record "filter2" ]

	set thickness_desired [ $grid.filter_desired get ]

	set i [ lsearch -exact $IMCAGui::thickness_list $thickness_desired ]

	if { $i < 0 } {
		set t "Attenuator thickness $thickness_desired not found in "
		append t "filter thickness list."

		tk_dialog .bad_filter_thickness_dialog \
		"Bad Attenuator Thickness" $t error 0 "OK"

		return
	}

	set index_list [ lindex $IMCAGui::thickness_indices $i ]

	set index1 [ lindex $index_list 0 ]
	set index2 [ lindex $index_list 1 ]

	set filter1_position $IMCAGui::filter1_position($index1)
	set filter2_position $IMCAGui::filter2_position($index2)

	set button .main.filter_frame.grid.move

	set_move_state_to_moving $button

	$filter1 move_absolute $filter1_position
	$filter2 move_absolute $filter2_position
}

proc get_filter_thickness {} {

	global callback_values
	global callback_records

	if [ $callback_records(filter1) is_busy ] {
		return "Moving"
	}
	if [ $callback_records(filter2) is_busy ] {
		return "Moving"
	}

	set threshold 10

	set position1 $callback_values(filter1)
	set position2 $callback_values(filter2)

	set thickness1 -1
	set thickness2 -1

	set nelements [ array size IMCAGui::filter1_position ]

	for { set i 0 } { $i < $nelements } { incr i } {

		set item_position $IMCAGui::filter1_position($i)

		set position_diff \
			[ expr ( abs( $item_position - $position1 ) ) ]

		if { $position_diff < $threshold } {
			set thickness1 $IMCAGui::filter1_thickness($i)
			break
		}
	}

	if { $thickness1 < 0 } {
		return "Fault"
	}

	set nelements [ array size IMCAGui::filter2_position ]

	for { set i 0 } { $i < $nelements } { incr i } {

		set item_position $IMCAGui::filter2_position($i)

		set position_diff \
			[ expr ( abs( $item_position - $position2 ) ) ]

		if { $position_diff < $threshold } {
			set thickness2 $IMCAGui::filter2_thickness($i)
			break
		}
	}

	if { $thickness2 < 0 } {
		return "Fault"
	}

	set result [ expr ( $thickness1 + $thickness2 ) ]

	return $result
}
